#!/bin/bash
# packager           : Fred. Galusik <fredg> (fred~AT~zenwalk.fr)
# source location    : http://dragontech.sourceforge.net/index.php?lang=en&main=news
# last revised       : 26/05/07

softname='Martian-Memory'
softversion='1.2'
packageversion='48.1'

arch='i686'
cpu='i686'

prefix=/usr

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.gz"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"

# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/doc/$softname-$softversion
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps/
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
   |-----handy-ruler------------------------------------------------------|
$softname: Simple memory game
$softname: 
$softname: Martian Memory is a very simple -Kids oriented-
$softname: memory game. 
$softname:  
$softname:   
$softname: 
$softname: 
$softname: 
$softname:
$softname: 
EOF

# extract the source code
cd $buildir
tar zxvf $srcpkg
cd $src

# configure package and install it to the target directory

    export CFLAGS="-O2 -march=$arch -mtune=$cpu"
    export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

    ./configure \
      --prefix=$prefix \
      --program-prefix="" \
      --program-suffix="" \

    make
    make install DESTDIR=$dest
        
# add 'default' files
    cp -a \
      COPYING AUTHORS INSTALL NEWS README ChangeLog\
      $dest/usr/doc/$softname-$softversion

# Strip
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)


# .desktop file
cat << "EOF" > $dest/usr/share/applications/$softname.desktop
[Desktop Entry]
Name=Martian-Memory
Name[fr]=Martian-Memory
Comment=a kids memory game
Comment[fr]=un jeu de mémoire pour enfants
Exec=martian
Icon=Martian-Memory
Categories=Game;KidsGame;
Terminal=false
Type=Application
Encoding=UTF-8
EOF

# Make the package freedesktop compliant
cp $buildir/$softname.png $dest/usr/share/icons/hicolor/48x48/apps/$softname.png

# remove unneeded
cd $dest
rm -rf $dest/usr/share/Martian/doc

# put the ZenWalk build and icon in the right directory
cd $buildir
   cp -a \
     build-$softname.sh $softname.png \
     $dest/usr/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# fix perm to let kids enter their highscores
chmod a+w $dest/var/lib/games/Martian/data/scores.dat

# real packaging work:
cd $dest
makepkg -l y -c n $dest.tgz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.tgz > $package.md5
